#!/usr/bin/env python

##############################################################################
# general PyTone configuration
##############################################################################

# basedir for filesystem based navigation and auto registering of songs
# in database
basedir = "/mnt/mp3"

# base name of songdb
songdbbase = "~/mp3"

# name of the file, where the played songs are logged
logfile = "~/pytone.log"

# here you can configure, whether the filelist and the playlist window, 
# respectively, have scrollbars
filelistwinhasscrollbar = 0
playlistwinhasscrollbar = 1


##############################################################################
# player configuration
#
# general format: 
#   name:    name of player
#   options: dictionary with player options
##############################################################################

##############################################################################
# mad: internal player (using libmad)
#
# options:
#   device:              libao device ("oss", "alsa", "alsa09", "esd", etc.)
#   dsp:                 path of dsp used for output
#   bufsize:             0:  no buffering by PyTone
#                        >0: size of internal buffer used for output in kBytes
#                        Note: A large buffer may prevent clicking but
#                        leads to a delayed response for instance to play next
#                        song requests
#   crossfadingstart:    start crossfading, if currently played song has only
#                        mixingstart seconds left
#   crossfadingduration: duration of crossfading in seconds
##############################################################################

# define two madplayers
# the first one uses /dev/dsp (with a 500 kByte large buffer) 
madplayer0 = {"name"   : "mad",
              "options": {"device"             : "oss",
                          "dsp"                : "/dev/dsp",
                          "bufsize"            : 500,
                          "crossfadingstart"   : 5,
                          "crossfadingduration": 6}
              }


# the second one outputs to  /dev/dsp1 and is unbuffered
madplayer1 = {"name"   : "mad",
              "options": {"device"             : "oss",
                          "dsp"                : "/dev/dsp1",
                          "bufsize"            : 1000,
                          "crossfadingstart"   : 5,
                          "crossfadingduration": 6}
              }

##############################################################################
# mpg123: external mpg321 or mpg123 based player
#
# options:
#   cmdline: cmdline use for the start of the player
##############################################################################

# define two mpg123 type external players (here mpg321) using /dev/dsp
# and /dev/dsp1

mpg123player0 = {"name"   : "mpg123",
                 "options": {"cmdline":
                             "/usr/bin/mpg321 --skip-printing-frames=5 -a /dev/dsp"}
                 }

mpg123player1 = {"name"   : "mpg123",
                 "options": {"cmdline":
                             "/usr/bin/mpg321 --skip-printing-frames=5 -a /dev/dsp1"}
                 }

##############################################################################
# xmms: external player using xmms
#
# options:
#   session: xmms session number
#   noqueue: 0=no internal queue for song
#            1=internal queue for songs, such that crossfading (via xmms-crossfade)
#              is possible
##############################################################################

xmmsplayer = {"name"   : "xmms",
              "options": {"session": 0,
                          "noqueue": 0}
              }

##############################################################################
# players: list of active players
##############################################################################

# a configuration with one player, which plays the songs in the playlist
players = [madplayer0]

# a configuration with two players: the first one plays the songs in the
# playlist, the second one always plays the currently selected song
# use this, if you have to soundcards or one with two line outs

# players = [madplayer0, madplayer1]
