#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses
import time

import item
import events
import window

from helper import formattime

class iteminfowin(window.window):
    def __init__(self, screen, h, w, y, x, player):
        self.item = None
        self.player = player
        events.ec.subscribe(events.selectionchanged, self.selectionchanged)
        window.window.__init__(self, screen, h, w, y, x, "MP3 Info")

    def selectionchanged(self, event):
        self.item = event.item
        if isinstance(self.item, item.song):
            events.ec.notify(events.nextsong(self.player, self.item))
        self.update()

    def update(self):
        window.window.update(self)
        if isinstance(self.item, item.song):
            l1 = "Title:  %s " % self.item.title
            if self.item.tracknr:
                r1 = " Nr:   %s " % self.item.tracknr
            else:
                r1 = ""
            l2 = "Album:  %s " % self.item.album
            if self.item.year!="" and self.item.year!="0":
                r2 = " Year: %s " % self.item.year
            else:
                r2 = ""
            l3 = "Artist: %s " % self.item.artist
            r3 = " Time:%s " % formattime(self.item.length)
            l4 = "Genre:  %s" % self.item.genre
            if self.item.nrplayed>0:
                last = int((time.time()-self.item.lastplayed)/60)
                lastplayed = "%2dh%02dm" % (divmod(last, 60))
                r4 = " Played: #%d, %s ago" % (self.item.nrplayed, lastplayed)
            else:
                r4 = ""
        elif isinstance(self.item, item.artist):
            l1 = "Artist: %s" % self.item.name
            r1 = l2 = r2 = l3 = r3 = l4 = r4 =""
        elif isinstance(self.item, item.album):
            l1 = "Artist: %s" % self.item.artist
            l2 = "Album:  %s" % self.item.name
            r1 = r2 = l3 = r3 = l4 = r4 = ""
        else:
            l1 = r1 = l2 = r2 = l3 = r3 = l4 = r4 = ""

        self.win.addstr(1, 1, l1.ljust(self.iw)[:self.iw], curses.A_BOLD)
        if r1!="":
            self.win.addstr(1, self.w-12, r1.ljust(11)[:11],     curses.A_BOLD)
        self.win.addstr(2, 1, l2.ljust(self.iw)[:self.iw], curses.A_BOLD)
        if r2!="":
            self.win.addstr(2, self.w-12, r2.ljust(11)[:11],     curses.A_BOLD)
        self.win.addstr(3, 1, l3.ljust(self.iw)[:self.iw], curses.A_BOLD)
        if r3!="":
            self.win.addstr(3, self.w-12, r3.ljust(11)[:11],     curses.A_BOLD)
        self.win.addstr(4, 1, l4.ljust(self.iw)[:self.iw], curses.A_BOLD)
        if r4!="":
            self.win.addstr(4, self.w-25, r4.ljust(24)[:24],     curses.A_BOLD)

        
        self.refresh()

        
