#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses

import window
import events
from helper import formattime


class playerwin(window.window):
    def __init__(self, screen, h, w, y, x, player):
        events.ec.subscribe(events.playbackinfochanged, self.playbackinfochanged)
        events.ec.subscribe(events.keypressed, self.keypressed)
        self.playing = 0
        self.title = None
        self.ttime = None
        self.ptime = None
        self.player = player
        window.window.__init__(self, screen, h, w, y, x, "Playback Info")
        self.update()

    def playbackinfochanged(self, event):
        if event.player is self.player:
            self.playing = event.playing
            self.title = event.title or "Playback Info"
            self.ptime = event.ptime
            self.ttime = event.ttime
            self.update()

    def keypressed(self, event):
        key = event.key
        if key in (ord("p"), ord("P")):
            events.ec.notify(events.playerstart(self.player))
        elif key in (ord("n"), ord("N")):
            events.ec.notify(events.playerforward(self.player))   
        elif key==ord("S"):
            events.ec.notify(events.playerstop(self.player))   
        else:
            return
        raise events.TerminateEventProcessing
        
    def update(self):
        window.window.update(self)
        if self.playing:
            output = " Time: %s/%s" % (formattime(self.ptime), formattime(self.ttime))
        else:
            output = ""

        self.win.addstr(1, 1, output.ljust(self.iw)[:self.iw], curses.A_BOLD)
        if self.playing:
            barlen = self.iw-20
            percentplayed = barlen*self.ptime/self.ttime
            self.win.move(1,20)
            for i in range(barlen):
                self.win.addch(ord("#"),
                               i<=percentplayed and curses.A_BOLD or curses.A_NORMAL)

        self.refresh()
