#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import time

import events
import slist

class playlistitem:
    def __init__(self, song):
        self.song = song
        self.played = 0

    def __repr__(self):
        return `self.song`

    def __getattr__(self, attr):
        return self.song.__dict__[attr]

    def play(self, player):
        self.played = 1
        self.song.play()
        events.ec.notify(events.nextsong(player, self.song))

    def hasbeenplayed(self):
        return self.played

    def isdir(self):
        return 0


class playlist(slist.slist):
    def __init__(self, win, logfilename=None):
        self.win = win
        self.logfilename = logfilename
        self.ttime = 0
        self.ptime = 0
        
        slist.slist.__init__(self, win.ih)
        
        events.ec.subscribe(events.addsongtoplaylist, self.addsongtoplaylist)
        events.ec.subscribe(events.requestnextsong, self.requestnextsong)
        

    def append(self, item):
        self.ttime += item.length
        slist.slist.append(self, item)

    def __delitem__(self, index):
        item = self[index]
        self.ttime -= item.length
        if item.hasbeenplayed():
            self.ptime -= item.length
        slist.slist.__delitem__(self, index)

    def clear(self):
        self.ttime = 0
        self.ptime = 0
        slist.slist.clear(self)
    
    def getselected(self):
        playlistitem = slist.slist.getselected(self)
        if playlistitem:
            return playlistitem.song
        else:
            return None

    def deleteplayedsongs(self):
        for i in range(len(self)-1,-1,-1):
            if self[i].hasbeenplayed():
                del self[i]

    def searchnextsong(self):
        for i in range(len(self)):
            if not self[i].hasbeenplayed():
                return self[i]
        return None

    # event handlers

    def addsongtoplaylist(self, event):
        self.append(playlistitem(event.song))
        self.win.update()

    def requestnextsong(self, event):
        nextsong = self.searchnextsong()
        if nextsong:
            self.ptime += nextsong.length
            nextsong.play(event.player)
            if self.logfilename:
                logfile = open(self.logfilename, "a")
                logfile.write("%s: %s\n" % (time.asctime(), nextsong.path))
                logfile.close()
        else:
            events.ec.notify(events.nextsong(event.player, None))
                
        self.win.update()



        



